@@ -532,7 +532,7 @@ DaapClient::passwordPrompt()
             KPasswordEdit* m_input;
     };
 
-    Daap::Reader* callback = dynamic_cast<Daap::Reader*>( const_cast<TQT_BASE_OBJECT_NAME*>( sender() ) );
+    Daap::Reader* callback = dynamic_cast<Daap::Reader*>( const_cast<TQObject*>( sender() ) );
     if (!callback) {
 	debug() << "No callback!" << endl;
 	return;
