@@ -64,7 +64,7 @@ namespace KDirStat
     //		class KDirTreeView: public KDirTreeViewParentClass
     // or some other 'ifdef' ... construct seems to confuse "moc".
     {
-	Q_OBJECT
+	TQ_OBJECT
   
 
     public:
