@@ -374,7 +374,7 @@ static void setUnsavedBLOBIdsForDataViewMode(
 	if (-1 != widget->metaObject()->findProperty("pixmapId")) {
 		const KexiBLOBBuffer::Id_t blobID = unsavedLocalBLOBsByName[ widget->name() ];
 		if (blobID > 0)
-			widget->setProperty("pixmapId", (uint /* KexiBLOBBuffer::Id_t is unsafe and unsupported by TQVariant - will be fixed in TQt4*/)blobID);
+			widget->setProperty("pixmapId", (uint)blobID);
 	}
 	const TQObjectList list = widget->childrenListObject();
 	if (list.isEmpty())
@@ -803,11 +803,11 @@ KexiFormView::storeData(bool dontAsk)
 				return false;
 			}
 			kexipluginsdbg << " storedDataID=" << storedBLOBID << endl;
-			h.setStoredWidthID((KexiBLOBBuffer::Id_t /*unsafe - will be fixed in TQt4*/)storedBLOBID);
+			h.setStoredWidthID((KexiBLOBBuffer::Id_t)storedBLOBID);
 			//set widget's internal property so it can be saved...
 			const TQVariant oldStoredPixmapId( it.key()->property("storedPixmapId") );
 			it.key()->setProperty("storedPixmapId", 
-				TQVariant((uint /* KexiBLOBBuffer::Id_t is unsafe and unsupported by TQVariant - will be fixed in TQt4*/)storedBLOBID));
+				TQVariant((uint)storedBLOBID));
 			KFormDesigner::ObjectTreeItem *widgetItem = designFormView->form()->objectTree()->lookup(it.key()->name()); //form()->objectTree()->lookup(it.key()->name());
 			if (widgetItem)
 				widgetItem->addModifiedProperty( "storedPixmapId", oldStoredPixmapId );
