@@ -26,7 +26,7 @@
 
 class DesktopComponent: public Component
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:  
   DesktopComponent( TQObject *parent = 0);
