@@ -29,7 +29,7 @@ namespace Kivio {
   */
   class KIVIO_EXPORT Plugin : public KParts::Plugin
   {
-    Q_OBJECT
+    TQ_OBJECT
   
     public:
       Plugin(KivioView* parent = 0, const char* name = 0);
