@@ -25,7 +25,7 @@ class IngredientList;
 
 class ShoppingListViewDialog: public KDialogBase
 {
-	Q_OBJECT
+	TQ_OBJECT
 
 public:
 	ShoppingListViewDialog( TQWidget *parent, const IngredientList &ingredientList );
