@@ -78,7 +78,7 @@ class TQTimer;
  * @version 0.7
 */
 class KNutNet : public TQObject  {
-   Q_OBJECT
+   TQ_OBJECT
   
 public: 
 
