@@ -212,7 +212,7 @@ static void gone_secure(void *opdata, ConnContext *context){
 	}
 
 #ifdef HAVE_LIBOTR_0400
-	session->setProperty("otr-instag", QString::number(context->their_instance));
+	session->setProperty("otr-instag", TQString::number(context->their_instance));
 #endif // HAVE_LIBOTR_0400
 }
 
